"""This module contains the general information for AaaExtMgmtCutThruTkn ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AaaExtMgmtCutThruTknConsts:
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    REMOTE_FALSE = "false"
    REMOTE_NO = "no"
    REMOTE_TRUE = "true"
    REMOTE_YES = "yes"
    TYPE_KVM = "kvm"


class AaaExtMgmtCutThruTkn(ManagedObject):
    """This is AaaExtMgmtCutThruTkn class."""

    consts = AaaExtMgmtCutThruTknConsts()
    naming_props = set(['token'])

    mo_meta = MoMeta("AaaExtMgmtCutThruTkn", "aaaExtMgmtCutThruTkn", "-[token]", VersionMeta.Version102d, "InputOutput", 0x1ff, [], ["aaa", "admin"], ['aaaUserEp'], [], ["Get"])

    prop_meta = {
        "auth_domain": MoPropertyMeta("auth_domain", "authDomain", "string", VersionMeta.Version203a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "auth_user": MoPropertyMeta("auth_user", "authUser", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version102d, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "creation_time": MoPropertyMeta("creation_time", "creationTime", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version102d, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version102d, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version102d, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "locales": MoPropertyMeta("locales", "locales", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version102d, MoPropertyMeta.CREATE_ONLY, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "pn_dn": MoPropertyMeta("pn_dn", "pnDn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["local", "pending-policy", "policy"], []),
        "priv": MoPropertyMeta("priv", "priv", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""((ext-lan-policy|pn-maintenance|ls-security-policy|pod-security|pn-equipment|ls-config-policy|ls-compute|ext-san-policy|ls-security|aaa|power-mgmt|read-only|ext-lan-security|ls-config|ls-server-policy|pod-qos|pn-policy|ls-storage-policy|org-management|admin|ext-san-security|pod-config|ls-server|ext-lan-qos|ls-storage|ls-qos-policy|operations|ext-lan-config|pn-security|ls-network-policy|pod-policy|ext-san-qos|ls-qos|ls-server-oper|ext-san-config|ls-network|ls-ext-access|fault),){0,37}(ext-lan-policy|pn-maintenance|ls-security-policy|pod-security|pn-equipment|ls-config-policy|ls-compute|ext-san-policy|ls-security|aaa|power-mgmt|read-only|ext-lan-security|ls-config|ls-server-policy|pod-qos|pn-policy|ls-storage-policy|org-management|admin|ext-san-security|pod-config|ls-server|ext-lan-qos|ls-storage|ls-qos-policy|operations|ext-lan-config|pn-security|ls-network-policy|pod-policy|ext-san-qos|ls-qos|ls-server-oper|ext-san-config|ls-network|ls-ext-access|fault){0,1}""", [], []),
        "remote": MoPropertyMeta("remote", "remote", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version102d, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version102d, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "token": MoPropertyMeta("token", "token", "string", VersionMeta.Version102d, MoPropertyMeta.NAMING, 0x100, 1, 510, None, [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version102d, MoPropertyMeta.READ_ONLY, None, None, None, None, ["kvm"], []),
        "user": MoPropertyMeta("user", "user", "string", VersionMeta.Version102d, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
    }

    prop_map = {
        "authDomain": "auth_domain", 
        "authUser": "auth_user", 
        "childAction": "child_action", 
        "creationTime": "creation_time", 
        "descr": "descr", 
        "dn": "dn", 
        "intId": "int_id", 
        "locales": "locales", 
        "name": "name", 
        "pnDn": "pn_dn", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "priv": "priv", 
        "remote": "remote", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "token": "token", 
        "type": "type", 
        "user": "user", 
    }

    def __init__(self, parent_mo_or_dn, token, **kwargs):
        self._dirty_mask = 0
        self.token = token
        self.auth_domain = None
        self.auth_user = None
        self.child_action = None
        self.creation_time = None
        self.descr = None
        self.int_id = None
        self.locales = None
        self.name = None
        self.pn_dn = None
        self.policy_level = None
        self.policy_owner = None
        self.priv = None
        self.remote = None
        self.sacl = None
        self.status = None
        self.type = None
        self.user = None

        ManagedObject.__init__(self, "AaaExtMgmtCutThruTkn", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ProcessorPMUStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ProcessorPMUStatsConsts:
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class ProcessorPMUStats(ManagedObject):
    """This is ProcessorPMUStats class."""

    consts = ProcessorPMUStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ProcessorPMUStats", "processorPMUStats", "pmu-stats", VersionMeta.Version412a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['processorUnit'], [], [None])

    prop_meta = {
        "system_management_unit_correctable_errors": MoPropertyMeta("system_management_unit_correctable_errors", "SystemManagementUnitCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_correctable_errors15_min": MoPropertyMeta("system_management_unit_correctable_errors15_min", "SystemManagementUnitCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_correctable_errors15_min_h": MoPropertyMeta("system_management_unit_correctable_errors15_min_h", "SystemManagementUnitCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_correctable_errors1_day": MoPropertyMeta("system_management_unit_correctable_errors1_day", "SystemManagementUnitCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_correctable_errors1_day_h": MoPropertyMeta("system_management_unit_correctable_errors1_day_h", "SystemManagementUnitCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_correctable_errors1_hour": MoPropertyMeta("system_management_unit_correctable_errors1_hour", "SystemManagementUnitCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_correctable_errors1_hour_h": MoPropertyMeta("system_management_unit_correctable_errors1_hour_h", "SystemManagementUnitCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_correctable_errors1_week": MoPropertyMeta("system_management_unit_correctable_errors1_week", "SystemManagementUnitCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_correctable_errors1_week_h": MoPropertyMeta("system_management_unit_correctable_errors1_week_h", "SystemManagementUnitCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_correctable_errors2_weeks": MoPropertyMeta("system_management_unit_correctable_errors2_weeks", "SystemManagementUnitCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_correctable_errors2_weeks_h": MoPropertyMeta("system_management_unit_correctable_errors2_weeks_h", "SystemManagementUnitCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_uncorrectable_errors": MoPropertyMeta("system_management_unit_uncorrectable_errors", "SystemManagementUnitUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_uncorrectable_errors15_min": MoPropertyMeta("system_management_unit_uncorrectable_errors15_min", "SystemManagementUnitUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_uncorrectable_errors15_min_h": MoPropertyMeta("system_management_unit_uncorrectable_errors15_min_h", "SystemManagementUnitUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_uncorrectable_errors1_day": MoPropertyMeta("system_management_unit_uncorrectable_errors1_day", "SystemManagementUnitUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_uncorrectable_errors1_day_h": MoPropertyMeta("system_management_unit_uncorrectable_errors1_day_h", "SystemManagementUnitUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_uncorrectable_errors1_hour": MoPropertyMeta("system_management_unit_uncorrectable_errors1_hour", "SystemManagementUnitUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_uncorrectable_errors1_hour_h": MoPropertyMeta("system_management_unit_uncorrectable_errors1_hour_h", "SystemManagementUnitUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_uncorrectable_errors1_week": MoPropertyMeta("system_management_unit_uncorrectable_errors1_week", "SystemManagementUnitUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_uncorrectable_errors1_week_h": MoPropertyMeta("system_management_unit_uncorrectable_errors1_week_h", "SystemManagementUnitUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_uncorrectable_errors2_weeks": MoPropertyMeta("system_management_unit_uncorrectable_errors2_weeks", "SystemManagementUnitUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "system_management_unit_uncorrectable_errors2_weeks_h": MoPropertyMeta("system_management_unit_uncorrectable_errors2_weeks_h", "SystemManagementUnitUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version412a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version412a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "SystemManagementUnitCorrectableErrors": "system_management_unit_correctable_errors", 
        "SystemManagementUnitCorrectableErrors15Min": "system_management_unit_correctable_errors15_min", 
        "SystemManagementUnitCorrectableErrors15MinH": "system_management_unit_correctable_errors15_min_h", 
        "SystemManagementUnitCorrectableErrors1Day": "system_management_unit_correctable_errors1_day", 
        "SystemManagementUnitCorrectableErrors1DayH": "system_management_unit_correctable_errors1_day_h", 
        "SystemManagementUnitCorrectableErrors1Hour": "system_management_unit_correctable_errors1_hour", 
        "SystemManagementUnitCorrectableErrors1HourH": "system_management_unit_correctable_errors1_hour_h", 
        "SystemManagementUnitCorrectableErrors1Week": "system_management_unit_correctable_errors1_week", 
        "SystemManagementUnitCorrectableErrors1WeekH": "system_management_unit_correctable_errors1_week_h", 
        "SystemManagementUnitCorrectableErrors2Weeks": "system_management_unit_correctable_errors2_weeks", 
        "SystemManagementUnitCorrectableErrors2WeeksH": "system_management_unit_correctable_errors2_weeks_h", 
        "SystemManagementUnitUncorrectableErrors": "system_management_unit_uncorrectable_errors", 
        "SystemManagementUnitUncorrectableErrors15Min": "system_management_unit_uncorrectable_errors15_min", 
        "SystemManagementUnitUncorrectableErrors15MinH": "system_management_unit_uncorrectable_errors15_min_h", 
        "SystemManagementUnitUncorrectableErrors1Day": "system_management_unit_uncorrectable_errors1_day", 
        "SystemManagementUnitUncorrectableErrors1DayH": "system_management_unit_uncorrectable_errors1_day_h", 
        "SystemManagementUnitUncorrectableErrors1Hour": "system_management_unit_uncorrectable_errors1_hour", 
        "SystemManagementUnitUncorrectableErrors1HourH": "system_management_unit_uncorrectable_errors1_hour_h", 
        "SystemManagementUnitUncorrectableErrors1Week": "system_management_unit_uncorrectable_errors1_week", 
        "SystemManagementUnitUncorrectableErrors1WeekH": "system_management_unit_uncorrectable_errors1_week_h", 
        "SystemManagementUnitUncorrectableErrors2Weeks": "system_management_unit_uncorrectable_errors2_weeks", 
        "SystemManagementUnitUncorrectableErrors2WeeksH": "system_management_unit_uncorrectable_errors2_weeks_h", 
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.system_management_unit_correctable_errors = None
        self.system_management_unit_correctable_errors15_min = None
        self.system_management_unit_correctable_errors15_min_h = None
        self.system_management_unit_correctable_errors1_day = None
        self.system_management_unit_correctable_errors1_day_h = None
        self.system_management_unit_correctable_errors1_hour = None
        self.system_management_unit_correctable_errors1_hour_h = None
        self.system_management_unit_correctable_errors1_week = None
        self.system_management_unit_correctable_errors1_week_h = None
        self.system_management_unit_correctable_errors2_weeks = None
        self.system_management_unit_correctable_errors2_weeks_h = None
        self.system_management_unit_uncorrectable_errors = None
        self.system_management_unit_uncorrectable_errors15_min = None
        self.system_management_unit_uncorrectable_errors15_min_h = None
        self.system_management_unit_uncorrectable_errors1_day = None
        self.system_management_unit_uncorrectable_errors1_day_h = None
        self.system_management_unit_uncorrectable_errors1_hour = None
        self.system_management_unit_uncorrectable_errors1_hour_h = None
        self.system_management_unit_uncorrectable_errors1_week = None
        self.system_management_unit_uncorrectable_errors1_week_h = None
        self.system_management_unit_uncorrectable_errors2_weeks = None
        self.system_management_unit_uncorrectable_errors2_weeks_h = None
        self.child_action = None
        self.intervals = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "ProcessorPMUStats", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of ConfigEstimateImpact ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigEstimateImpact", "configEstimateImpact", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_configs": MethodPropertyMeta("InConfigs", "inConfigs", "ConfigMap", "Version142b", "Input", True),
    "out_ackables": MethodPropertyMeta("OutAckables", "outAckables", "ConfigMap", "Version142b", "Output", True),
    "out_affected": MethodPropertyMeta("OutAffected", "outAffected", "ConfigMap", "Version142b", "Output", True),
    "out_old_ackables": MethodPropertyMeta("OutOldAckables", "outOldAckables", "ConfigMap", "Version142b", "Output", True),
    "out_old_affected": MethodPropertyMeta("OutOldAffected", "outOldAffected", "ConfigMap", "Version142b", "Output", True),
    "out_retry": MethodPropertyMeta("OutRetry", "outRetry", "Xs:unsignedShort", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inConfigs": "in_configs",
    "outAckables": "out_ackables",
    "outAffected": "out_affected",
    "outOldAckables": "out_old_ackables",
    "outOldAffected": "out_old_affected",
    "outRetry": "out_retry",
}



"""This module contains the general information for AdaptorCapQual ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AdaptorCapQualConsts:
    FW_VERSION_OPR_GT = "gt"
    FW_VERSION_OPR_LT = "lt"
    FW_VERSION_OPR_NONE = "none"
    FW_VERSION_OPR_RANGE = "range"
    MAXIMUM_UNSPECIFIED = "unspecified"
    TYPE_CDN_SUPPORT = "cdn-support"
    TYPE_ETH_FLOW_MONITORING_NETFLOW = "eth-flow-monitoring-netflow"
    TYPE_ETH_NVGRE = "eth-nvgre"
    TYPE_ETH_NVGRE_ROCEV2 = "eth-nvgre-rocev2"
    TYPE_ETH_NVGRE_VMQ = "eth-nvgre-vmq"
    TYPE_ETH_ROCE = "eth-roce"
    TYPE_ETH_ROCE_V2 = "eth-roce-v2"
    TYPE_ETH_VXLAN = "eth-vxlan"
    TYPE_ETH_VXLAN_ROCEV2 = "eth-vxlan-rocev2"
    TYPE_ETH_VXLAN_VMQ = "eth-vxlan-vmq"
    TYPE_FCOE = "fcoe"
    TYPE_NON_VIRTUALIZED_ETH_IF = "non-virtualized-eth-if"
    TYPE_NON_VIRTUALIZED_FC_IF = "non-virtualized-fc-if"
    TYPE_ORACLE_RAC_SUPPORT = "oracle-rac-support"
    TYPE_PATH_ENCAP_CONSOLIDATED = "path-encap-consolidated"
    TYPE_PATH_ENCAP_VIRTUAL = "path-encap-virtual"
    TYPE_PATH_ENCAP_VIRTUAL_CE = "path-encap-virtual-ce"
    TYPE_PROTECTED_ETH_IF = "protected-eth-if"
    TYPE_PROTECTED_FC_IF = "protected-fc-if"
    TYPE_PROTECTED_FCOE = "protected-fcoe"
    TYPE_PXEBOOT_CONFIG_SUPPORT = "pxeboot-config-support"
    TYPE_UPLINK_AGGREGATION = "uplink-aggregation"
    TYPE_VIRTUALIZED_CE_ETH_IF = "virtualized-ce-eth-if"
    TYPE_VIRTUALIZED_ETH_IF = "virtualized-eth-if"
    TYPE_VIRTUALIZED_ETH_SRIOV = "virtualized-eth-sriov"
    TYPE_VIRTUALIZED_ETH_SRIOV_USNIC = "virtualized-eth-sriov-usnic"
    TYPE_VIRTUALIZED_ETH_VMMQ = "virtualized-eth-vmmq"
    TYPE_VIRTUALIZED_ETH_VMQ = "virtualized-eth-vmq"
    TYPE_VIRTUALIZED_FC_IF = "virtualized-fc-if"
    TYPE_VIRTUALIZED_FC_SRIOV = "virtualized-fc-sriov"
    TYPE_VIRTUALIZED_SCSI_IF = "virtualized-scsi-if"


class AdaptorCapQual(ManagedObject):
    """This is AdaptorCapQual class."""

    consts = AdaptorCapQualConsts()
    naming_props = set(['type'])

    mo_meta = MoMeta("AdaptorCapQual", "adaptorCapQual", "cap-[type]", VersionMeta.Version101e, "InputOutput", 0xff, [], ["admin", "pn-policy"], ['adaptorQual'], [], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "fw_version_hi": MoPropertyMeta("fw_version_hi", "fwVersionHi", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "fw_version_lo": MoPropertyMeta("fw_version_lo", "fwVersionLo", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "fw_version_opr": MoPropertyMeta("fw_version_opr", "fwVersionOpr", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["gt", "lt", "none", "range"], []),
        "maximum": MoPropertyMeta("maximum", "maximum", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["unspecified"], ["0-65535", "4294967295-4294967295"]),
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[ !#$%\(\)\*\+,\-\./:;\?@\[\\\]\^_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "nf_version_lo": MoPropertyMeta("nf_version_lo", "nfVersionLo", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x80, None, None, None, ["cdn-support", "eth-flow-monitoring-netflow", "eth-nvgre", "eth-nvgre-rocev2", "eth-nvgre-vmq", "eth-roce", "eth-roce-v2", "eth-vxlan", "eth-vxlan-rocev2", "eth-vxlan-vmq", "fcoe", "non-virtualized-eth-if", "non-virtualized-fc-if", "oracle-rac-support", "path-encap-consolidated", "path-encap-virtual", "path-encap-virtual-ce", "protected-eth-if", "protected-fc-if", "protected-fcoe", "pxeboot-config-support", "uplink-aggregation", "virtualized-ce-eth-if", "virtualized-eth-if", "virtualized-eth-sriov", "virtualized-eth-sriov-usnic", "virtualized-eth-vmmq", "virtualized-eth-vmq", "virtualized-fc-if", "virtualized-fc-sriov", "virtualized-scsi-if"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "fwVersionHi": "fw_version_hi", 
        "fwVersionLo": "fw_version_lo", 
        "fwVersionOpr": "fw_version_opr", 
        "maximum": "maximum", 
        "model": "model", 
        "nfVersionLo": "nf_version_lo", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.child_action = None
        self.fw_version_hi = None
        self.fw_version_lo = None
        self.fw_version_opr = None
        self.maximum = None
        self.model = None
        self.nf_version_lo = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "AdaptorCapQual", parent_mo_or_dn, **kwargs)



"""This module contains the general information for HostimgTarget ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class HostimgTargetConsts:
    ORDER_UNSPECIFIED = "unspecified"
    TYPE_COMPLETE = "complete"
    TYPE_FILE_SYSTEM = "file-system"
    TYPE_GPXE_SCRIPT = "gpxe-script"
    TYPE_KERNEL = "kernel"
    TYPE_MODULE = "module"


class HostimgTarget(ManagedObject):
    """This is HostimgTarget class."""

    consts = HostimgTargetConsts()
    naming_props = set(['type', 'name'])

    mo_meta = MoMeta("HostimgTarget", "hostimgTarget", "target-[type]-comp-[name]", VersionMeta.Version141i, "InputOutput", 0x1ff, [], ["admin", "ls-compute", "ls-config", "ls-config-policy", "ls-server"], ['hostimgPolicy'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141i, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version141i, MoPropertyMeta.NAMING, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "order": MoPropertyMeta("order", "order", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["unspecified"], ["0-65535"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version141i, MoPropertyMeta.NAMING, 0x80, None, None, None, ["complete", "file-system", "gpxe-script", "kernel", "module"], []),
        "uri": MoPropertyMeta("uri", "uri", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "name": "name", 
        "order": "order", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
        "uri": "uri", 
    }

    def __init__(self, parent_mo_or_dn, type, name, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.name = name
        self.child_action = None
        self.order = None
        self.sacl = None
        self.status = None
        self.uri = None

        ManagedObject.__init__(self, "HostimgTarget", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ProcessorPCIBusStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ProcessorPCIBusStatsConsts:
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class ProcessorPCIBusStats(ManagedObject):
    """This is ProcessorPCIBusStats class."""

    consts = ProcessorPCIBusStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ProcessorPCIBusStats", "processorPCIBusStats", "pcibus-stats", VersionMeta.Version412a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['processorUnit'], [], [None])

    prop_meta = {
        "fch_uncorrectable_errors": MoPropertyMeta("fch_uncorrectable_errors", "FCHUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fch_uncorrectable_errors15_min": MoPropertyMeta("fch_uncorrectable_errors15_min", "FCHUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fch_uncorrectable_errors15_min_h": MoPropertyMeta("fch_uncorrectable_errors15_min_h", "FCHUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fch_uncorrectable_errors1_day": MoPropertyMeta("fch_uncorrectable_errors1_day", "FCHUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fch_uncorrectable_errors1_day_h": MoPropertyMeta("fch_uncorrectable_errors1_day_h", "FCHUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fch_uncorrectable_errors1_hour": MoPropertyMeta("fch_uncorrectable_errors1_hour", "FCHUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fch_uncorrectable_errors1_hour_h": MoPropertyMeta("fch_uncorrectable_errors1_hour_h", "FCHUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fch_uncorrectable_errors1_week": MoPropertyMeta("fch_uncorrectable_errors1_week", "FCHUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fch_uncorrectable_errors1_week_h": MoPropertyMeta("fch_uncorrectable_errors1_week_h", "FCHUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fch_uncorrectable_errors2_weeks": MoPropertyMeta("fch_uncorrectable_errors2_weeks", "FCHUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fch_uncorrectable_errors2_weeks_h": MoPropertyMeta("fch_uncorrectable_errors2_weeks_h", "FCHUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fc_hcorrectable_errors": MoPropertyMeta("fc_hcorrectable_errors", "FCHcorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fc_hcorrectable_errors15_min": MoPropertyMeta("fc_hcorrectable_errors15_min", "FCHcorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fc_hcorrectable_errors15_min_h": MoPropertyMeta("fc_hcorrectable_errors15_min_h", "FCHcorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fc_hcorrectable_errors1_day": MoPropertyMeta("fc_hcorrectable_errors1_day", "FCHcorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fc_hcorrectable_errors1_day_h": MoPropertyMeta("fc_hcorrectable_errors1_day_h", "FCHcorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fc_hcorrectable_errors1_hour": MoPropertyMeta("fc_hcorrectable_errors1_hour", "FCHcorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fc_hcorrectable_errors1_hour_h": MoPropertyMeta("fc_hcorrectable_errors1_hour_h", "FCHcorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fc_hcorrectable_errors1_week": MoPropertyMeta("fc_hcorrectable_errors1_week", "FCHcorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fc_hcorrectable_errors1_week_h": MoPropertyMeta("fc_hcorrectable_errors1_week_h", "FCHcorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fc_hcorrectable_errors2_weeks": MoPropertyMeta("fc_hcorrectable_errors2_weeks", "FCHcorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "fc_hcorrectable_errors2_weeks_h": MoPropertyMeta("fc_hcorrectable_errors2_weeks_h", "FCHcorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_correctable_errors": MoPropertyMeta("north_bridge_io_correctable_errors", "NorthBridgeIOCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_correctable_errors15_min": MoPropertyMeta("north_bridge_io_correctable_errors15_min", "NorthBridgeIOCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_correctable_errors15_min_h": MoPropertyMeta("north_bridge_io_correctable_errors15_min_h", "NorthBridgeIOCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_correctable_errors1_day": MoPropertyMeta("north_bridge_io_correctable_errors1_day", "NorthBridgeIOCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_correctable_errors1_day_h": MoPropertyMeta("north_bridge_io_correctable_errors1_day_h", "NorthBridgeIOCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_correctable_errors1_hour": MoPropertyMeta("north_bridge_io_correctable_errors1_hour", "NorthBridgeIOCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_correctable_errors1_hour_h": MoPropertyMeta("north_bridge_io_correctable_errors1_hour_h", "NorthBridgeIOCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_correctable_errors1_week": MoPropertyMeta("north_bridge_io_correctable_errors1_week", "NorthBridgeIOCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_correctable_errors1_week_h": MoPropertyMeta("north_bridge_io_correctable_errors1_week_h", "NorthBridgeIOCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_correctable_errors2_weeks": MoPropertyMeta("north_bridge_io_correctable_errors2_weeks", "NorthBridgeIOCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_correctable_errors2_weeks_h": MoPropertyMeta("north_bridge_io_correctable_errors2_weeks_h", "NorthBridgeIOCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_uncorrectable_errors": MoPropertyMeta("north_bridge_io_uncorrectable_errors", "NorthBridgeIOUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_uncorrectable_errors15_min": MoPropertyMeta("north_bridge_io_uncorrectable_errors15_min", "NorthBridgeIOUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_uncorrectable_errors15_min_h": MoPropertyMeta("north_bridge_io_uncorrectable_errors15_min_h", "NorthBridgeIOUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_uncorrectable_errors1_day": MoPropertyMeta("north_bridge_io_uncorrectable_errors1_day", "NorthBridgeIOUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_uncorrectable_errors1_day_h": MoPropertyMeta("north_bridge_io_uncorrectable_errors1_day_h", "NorthBridgeIOUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_uncorrectable_errors1_hour": MoPropertyMeta("north_bridge_io_uncorrectable_errors1_hour", "NorthBridgeIOUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_uncorrectable_errors1_hour_h": MoPropertyMeta("north_bridge_io_uncorrectable_errors1_hour_h", "NorthBridgeIOUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_uncorrectable_errors1_week": MoPropertyMeta("north_bridge_io_uncorrectable_errors1_week", "NorthBridgeIOUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_uncorrectable_errors1_week_h": MoPropertyMeta("north_bridge_io_uncorrectable_errors1_week_h", "NorthBridgeIOUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_uncorrectable_errors2_weeks": MoPropertyMeta("north_bridge_io_uncorrectable_errors2_weeks", "NorthBridgeIOUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "north_bridge_io_uncorrectable_errors2_weeks_h": MoPropertyMeta("north_bridge_io_uncorrectable_errors2_weeks_h", "NorthBridgeIOUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version412a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version412a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "FCHUncorrectableErrors": "fch_uncorrectable_errors", 
        "FCHUncorrectableErrors15Min": "fch_uncorrectable_errors15_min", 
        "FCHUncorrectableErrors15MinH": "fch_uncorrectable_errors15_min_h", 
        "FCHUncorrectableErrors1Day": "fch_uncorrectable_errors1_day", 
        "FCHUncorrectableErrors1DayH": "fch_uncorrectable_errors1_day_h", 
        "FCHUncorrectableErrors1Hour": "fch_uncorrectable_errors1_hour", 
        "FCHUncorrectableErrors1HourH": "fch_uncorrectable_errors1_hour_h", 
        "FCHUncorrectableErrors1Week": "fch_uncorrectable_errors1_week", 
        "FCHUncorrectableErrors1WeekH": "fch_uncorrectable_errors1_week_h", 
        "FCHUncorrectableErrors2Weeks": "fch_uncorrectable_errors2_weeks", 
        "FCHUncorrectableErrors2WeeksH": "fch_uncorrectable_errors2_weeks_h", 
        "FCHcorrectableErrors": "fc_hcorrectable_errors", 
        "FCHcorrectableErrors15Min": "fc_hcorrectable_errors15_min", 
        "FCHcorrectableErrors15MinH": "fc_hcorrectable_errors15_min_h", 
        "FCHcorrectableErrors1Day": "fc_hcorrectable_errors1_day", 
        "FCHcorrectableErrors1DayH": "fc_hcorrectable_errors1_day_h", 
        "FCHcorrectableErrors1Hour": "fc_hcorrectable_errors1_hour", 
        "FCHcorrectableErrors1HourH": "fc_hcorrectable_errors1_hour_h", 
        "FCHcorrectableErrors1Week": "fc_hcorrectable_errors1_week", 
        "FCHcorrectableErrors1WeekH": "fc_hcorrectable_errors1_week_h", 
        "FCHcorrectableErrors2Weeks": "fc_hcorrectable_errors2_weeks", 
        "FCHcorrectableErrors2WeeksH": "fc_hcorrectable_errors2_weeks_h", 
        "NorthBridgeIOCorrectableErrors": "north_bridge_io_correctable_errors", 
        "NorthBridgeIOCorrectableErrors15Min": "north_bridge_io_correctable_errors15_min", 
        "NorthBridgeIOCorrectableErrors15MinH": "north_bridge_io_correctable_errors15_min_h", 
        "NorthBridgeIOCorrectableErrors1Day": "north_bridge_io_correctable_errors1_day", 
        "NorthBridgeIOCorrectableErrors1DayH": "north_bridge_io_correctable_errors1_day_h", 
        "NorthBridgeIOCorrectableErrors1Hour": "north_bridge_io_correctable_errors1_hour", 
        "NorthBridgeIOCorrectableErrors1HourH": "north_bridge_io_correctable_errors1_hour_h", 
        "NorthBridgeIOCorrectableErrors1Week": "north_bridge_io_correctable_errors1_week", 
        "NorthBridgeIOCorrectableErrors1WeekH": "north_bridge_io_correctable_errors1_week_h", 
        "NorthBridgeIOCorrectableErrors2Weeks": "north_bridge_io_correctable_errors2_weeks", 
        "NorthBridgeIOCorrectableErrors2WeeksH": "north_bridge_io_correctable_errors2_weeks_h", 
        "NorthBridgeIOUncorrectableErrors": "north_bridge_io_uncorrectable_errors", 
        "NorthBridgeIOUncorrectableErrors15Min": "north_bridge_io_uncorrectable_errors15_min", 
        "NorthBridgeIOUncorrectableErrors15MinH": "north_bridge_io_uncorrectable_errors15_min_h", 
        "NorthBridgeIOUncorrectableErrors1Day": "north_bridge_io_uncorrectable_errors1_day", 
        "NorthBridgeIOUncorrectableErrors1DayH": "north_bridge_io_uncorrectable_errors1_day_h", 
        "NorthBridgeIOUncorrectableErrors1Hour": "north_bridge_io_uncorrectable_errors1_hour", 
        "NorthBridgeIOUncorrectableErrors1HourH": "north_bridge_io_uncorrectable_errors1_hour_h", 
        "NorthBridgeIOUncorrectableErrors1Week": "north_bridge_io_uncorrectable_errors1_week", 
        "NorthBridgeIOUncorrectableErrors1WeekH": "north_bridge_io_uncorrectable_errors1_week_h", 
        "NorthBridgeIOUncorrectableErrors2Weeks": "north_bridge_io_uncorrectable_errors2_weeks", 
        "NorthBridgeIOUncorrectableErrors2WeeksH": "north_bridge_io_uncorrectable_errors2_weeks_h", 
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.fch_uncorrectable_errors = None
        self.fch_uncorrectable_errors15_min = None
        self.fch_uncorrectable_errors15_min_h = None
        self.fch_uncorrectable_errors1_day = None
        self.fch_uncorrectable_errors1_day_h = None
        self.fch_uncorrectable_errors1_hour = None
        self.fch_uncorrectable_errors1_hour_h = None
        self.fch_uncorrectable_errors1_week = None
        self.fch_uncorrectable_errors1_week_h = None
        self.fch_uncorrectable_errors2_weeks = None
        self.fch_uncorrectable_errors2_weeks_h = None
        self.fc_hcorrectable_errors = None
        self.fc_hcorrectable_errors15_min = None
        self.fc_hcorrectable_errors15_min_h = None
        self.fc_hcorrectable_errors1_day = None
        self.fc_hcorrectable_errors1_day_h = None
        self.fc_hcorrectable_errors1_hour = None
        self.fc_hcorrectable_errors1_hour_h = None
        self.fc_hcorrectable_errors1_week = None
        self.fc_hcorrectable_errors1_week_h = None
        self.fc_hcorrectable_errors2_weeks = None
        self.fc_hcorrectable_errors2_weeks_h = None
        self.north_bridge_io_correctable_errors = None
        self.north_bridge_io_correctable_errors15_min = None
        self.north_bridge_io_correctable_errors15_min_h = None
        self.north_bridge_io_correctable_errors1_day = None
        self.north_bridge_io_correctable_errors1_day_h = None
        self.north_bridge_io_correctable_errors1_hour = None
        self.north_bridge_io_correctable_errors1_hour_h = None
        self.north_bridge_io_correctable_errors1_week = None
        self.north_bridge_io_correctable_errors1_week_h = None
        self.north_bridge_io_correctable_errors2_weeks = None
        self.north_bridge_io_correctable_errors2_weeks_h = None
        self.north_bridge_io_uncorrectable_errors = None
        self.north_bridge_io_uncorrectable_errors15_min = None
        self.north_bridge_io_uncorrectable_errors15_min_h = None
        self.north_bridge_io_uncorrectable_errors1_day = None
        self.north_bridge_io_uncorrectable_errors1_day_h = None
        self.north_bridge_io_uncorrectable_errors1_hour = None
        self.north_bridge_io_uncorrectable_errors1_hour_h = None
        self.north_bridge_io_uncorrectable_errors1_week = None
        self.north_bridge_io_uncorrectable_errors1_week_h = None
        self.north_bridge_io_uncorrectable_errors2_weeks = None
        self.north_bridge_io_uncorrectable_errors2_weeks_h = None
        self.child_action = None
        self.intervals = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "ProcessorPCIBusStats", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ComputeBladeEp ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ComputeBladeEpConsts:
    ADMIN_STATE_IN_MAINTENANCE = "in-maintenance"
    ADMIN_STATE_IN_SERVICE = "in-service"
    ADMIN_STATE_OUT_OF_SERVICE = "out-of-service"
    CHASSIS_ID_N_A = "N/A"
    OPER_STATE_BIOS_RESTORE = "bios-restore"
    OPER_STATE_CMOS_RESET = "cmos-reset"
    OPER_STATE_COMPUTE_FAILED = "compute-failed"
    OPER_STATE_COMPUTE_MISMATCH = "compute-mismatch"
    OPER_STATE_CONFIG = "config"
    OPER_STATE_CONFIG_FAILURE = "config-failure"
    OPER_STATE_DECOMISSIONING = "decomissioning"
    OPER_STATE_DEGRADED = "degraded"
    OPER_STATE_DIAGNOSTICS = "diagnostics"
    OPER_STATE_DIAGNOSTICS_FAILED = "diagnostics-failed"
    OPER_STATE_DISABLED = "disabled"
    OPER_STATE_DISCOVERY = "discovery"
    OPER_STATE_DISCOVERY_FAILED = "discovery-failed"
    OPER_STATE_INACCESSIBLE = "inaccessible"
    OPER_STATE_INDETERMINATE = "indeterminate"
    OPER_STATE_INOPERABLE = "inoperable"
    OPER_STATE_MAINTENANCE = "maintenance"
    OPER_STATE_MAINTENANCE_FAILED = "maintenance-failed"
    OPER_STATE_OK = "ok"
    OPER_STATE_PENDING_REASSOCIATION = "pending-reassociation"
    OPER_STATE_PENDING_REBOOT = "pending-reboot"
    OPER_STATE_POWER_OFF = "power-off"
    OPER_STATE_POWER_PROBLEM = "power-problem"
    OPER_STATE_REMOVED = "removed"
    OPER_STATE_RESTART = "restart"
    OPER_STATE_SVNIC_NOT_PRESENT = "svnic-not-present"
    OPER_STATE_TEST = "test"
    OPER_STATE_TEST_FAILED = "test-failed"
    OPER_STATE_THERMAL_PROBLEM = "thermal-problem"
    OPER_STATE_UNASSOCIATED = "unassociated"
    OPER_STATE_UNCONFIG = "unconfig"
    OPER_STATE_UNCONFIG_FAILED = "unconfig-failed"
    OPER_STATE_VOLTAGE_PROBLEM = "voltage-problem"
    PEER_PRESENCE_EMPTY = "empty"
    PEER_PRESENCE_EQUIPPED = "equipped"
    PEER_PRESENCE_EQUIPPED_DEPRECATED = "equipped-deprecated"
    PEER_PRESENCE_EQUIPPED_IDENTITY_UNESTABLISHABLE = "equipped-identity-unestablishable"
    PEER_PRESENCE_EQUIPPED_NOT_PRIMARY = "equipped-not-primary"
    PEER_PRESENCE_EQUIPPED_SLAVE = "equipped-slave"
    PEER_PRESENCE_EQUIPPED_UNSUPPORTED = "equipped-unsupported"
    PEER_PRESENCE_EQUIPPED_WITH_MALFORMED_FRU = "equipped-with-malformed-fru"
    PEER_PRESENCE_INACCESSIBLE = "inaccessible"
    PEER_PRESENCE_MISMATCH = "mismatch"
    PEER_PRESENCE_MISMATCH_IDENTITY_UNESTABLISHABLE = "mismatch-identity-unestablishable"
    PEER_PRESENCE_MISMATCH_SLAVE = "mismatch-slave"
    PEER_PRESENCE_MISSING = "missing"
    PEER_PRESENCE_MISSING_SLAVE = "missing-slave"
    PEER_PRESENCE_UNAUTHORIZED = "unauthorized"
    PEER_PRESENCE_UNKNOWN = "unknown"
    PRESENCE_EMPTY = "empty"
    PRESENCE_EQUIPPED = "equipped"
    PRESENCE_EQUIPPED_DEPRECATED = "equipped-deprecated"
    PRESENCE_EQUIPPED_IDENTITY_UNESTABLISHABLE = "equipped-identity-unestablishable"
    PRESENCE_EQUIPPED_NOT_PRIMARY = "equipped-not-primary"
    PRESENCE_EQUIPPED_SLAVE = "equipped-slave"
    PRESENCE_EQUIPPED_UNSUPPORTED = "equipped-unsupported"
    PRESENCE_EQUIPPED_WITH_MALFORMED_FRU = "equipped-with-malformed-fru"
    PRESENCE_INACCESSIBLE = "inaccessible"
    PRESENCE_MISMATCH = "mismatch"
    PRESENCE_MISMATCH_IDENTITY_UNESTABLISHABLE = "mismatch-identity-unestablishable"
    PRESENCE_MISMATCH_SLAVE = "mismatch-slave"
    PRESENCE_MISSING = "missing"
    PRESENCE_MISSING_SLAVE = "missing-slave"
    PRESENCE_UNAUTHORIZED = "unauthorized"
    PRESENCE_UNKNOWN = "unknown"


class ComputeBladeEp(ManagedObject):
    """This is ComputeBladeEp class."""

    consts = ComputeBladeEpConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("ComputeBladeEp", "computeBladeEp", "blade-ep-[id]", VersionMeta.Version302c, "InputOutput", 0x3f, [], ["read-only"], [], [], [None])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["in-maintenance", "in-service", "out-of-service"], []),
        "chassis_id": MoPropertyMeta("chassis_id", "chassisId", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A"], ["0-255"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version302c, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version302c, MoPropertyMeta.NAMING, 0x8, None, None, None, [], ["1-2"]),
        "oper_qualifier_reason": MoPropertyMeta("oper_qualifier_reason", "operQualifierReason", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["bios-restore", "cmos-reset", "compute-failed", "compute-mismatch", "config", "config-failure", "decomissioning", "degraded", "diagnostics", "diagnostics-failed", "disabled", "discovery", "discovery-failed", "inaccessible", "indeterminate", "inoperable", "maintenance", "maintenance-failed", "ok", "pending-reassociation", "pending-reboot", "power-off", "power-problem", "removed", "restart", "svnic-not-present", "test", "test-failed", "thermal-problem", "unassociated", "unconfig", "unconfig-failed", "voltage-problem"], []),
        "peer_presence": MoPropertyMeta("peer_presence", "peerPresence", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["empty", "equipped", "equipped-deprecated", "equipped-identity-unestablishable", "equipped-not-primary", "equipped-slave", "equipped-unsupported", "equipped-with-malformed-fru", "inaccessible", "mismatch", "mismatch-identity-unestablishable", "mismatch-slave", "missing", "missing-slave", "unauthorized", "unknown"], []),
        "presence": MoPropertyMeta("presence", "presence", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["empty", "equipped", "equipped-deprecated", "equipped-identity-unestablishable", "equipped-not-primary", "equipped-slave", "equipped-unsupported", "equipped-with-malformed-fru", "inaccessible", "mismatch", "mismatch-identity-unestablishable", "mismatch-slave", "missing", "missing-slave", "unauthorized", "unknown"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "slot_id": MoPropertyMeta("slot_id", "slotId", "uint", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["1-8"]),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version302c, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "adminState": "admin_state", 
        "chassisId": "chassis_id", 
        "childAction": "child_action", 
        "dn": "dn", 
        "epDn": "ep_dn", 
        "id": "id", 
        "operQualifierReason": "oper_qualifier_reason", 
        "operState": "oper_state", 
        "peerPresence": "peer_presence", 
        "presence": "presence", 
        "rn": "rn", 
        "sacl": "sacl", 
        "slotId": "slot_id", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.admin_state = None
        self.chassis_id = None
        self.child_action = None
        self.ep_dn = None
        self.oper_qualifier_reason = None
        self.oper_state = None
        self.peer_presence = None
        self.presence = None
        self.sacl = None
        self.slot_id = None
        self.status = None

        ManagedObject.__init__(self, "ComputeBladeEp", parent_mo_or_dn, **kwargs)



"""This module contains the general information for EquipmentIOCardStatsHist ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EquipmentIOCardStatsHistConsts:
    AMBIENT_TEMP_NOT_APPLICABLE = "not-applicable"
    AMBIENT_TEMP_AVG_NOT_APPLICABLE = "not-applicable"
    AMBIENT_TEMP_MAX_NOT_APPLICABLE = "not-applicable"
    AMBIENT_TEMP_MIN_NOT_APPLICABLE = "not-applicable"
    DIMM_TEMP_NOT_APPLICABLE = "not-applicable"
    DIMM_TEMP_AVG_NOT_APPLICABLE = "not-applicable"
    DIMM_TEMP_MAX_NOT_APPLICABLE = "not-applicable"
    DIMM_TEMP_MIN_NOT_APPLICABLE = "not-applicable"
    MOST_RECENT_FALSE = "false"
    MOST_RECENT_NO = "no"
    MOST_RECENT_TRUE = "true"
    MOST_RECENT_YES = "yes"
    PROC_TEMP_NOT_APPLICABLE = "not-applicable"
    PROC_TEMP_AVG_NOT_APPLICABLE = "not-applicable"
    PROC_TEMP_MAX_NOT_APPLICABLE = "not-applicable"
    PROC_TEMP_MIN_NOT_APPLICABLE = "not-applicable"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"
    TEMP_NOT_APPLICABLE = "not-applicable"
    TEMP_AVG_NOT_APPLICABLE = "not-applicable"
    TEMP_MAX_NOT_APPLICABLE = "not-applicable"
    TEMP_MIN_NOT_APPLICABLE = "not-applicable"


class EquipmentIOCardStatsHist(ManagedObject):
    """This is EquipmentIOCardStatsHist class."""

    consts = EquipmentIOCardStatsHistConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("EquipmentIOCardStatsHist", "equipmentIOCardStatsHist", "[id]", VersionMeta.Version111j, "OutputOnly", 0xf, [], ["read-only"], ['equipmentIOCardStats'], [], ["Get"])

    prop_meta = {
        "iom_i2_c_errors": MoPropertyMeta("iom_i2_c_errors", "IomI2CErrors", "ulong", VersionMeta.Version226c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "iom_i2_c_errors_avg": MoPropertyMeta("iom_i2_c_errors_avg", "IomI2CErrorsAvg", "ulong", VersionMeta.Version227b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "iom_i2_c_errors_max": MoPropertyMeta("iom_i2_c_errors_max", "IomI2CErrorsMax", "ulong", VersionMeta.Version227b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "iom_i2_c_errors_min": MoPropertyMeta("iom_i2_c_errors_min", "IomI2CErrorsMin", "ulong", VersionMeta.Version227b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ambient_temp": MoPropertyMeta("ambient_temp", "ambientTemp", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "ambient_temp_avg": MoPropertyMeta("ambient_temp_avg", "ambientTempAvg", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "ambient_temp_max": MoPropertyMeta("ambient_temp_max", "ambientTempMax", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "ambient_temp_min": MoPropertyMeta("ambient_temp_min", "ambientTempMin", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dimm_temp": MoPropertyMeta("dimm_temp", "dimmTemp", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "dimm_temp_avg": MoPropertyMeta("dimm_temp_avg", "dimmTempAvg", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "dimm_temp_max": MoPropertyMeta("dimm_temp_max", "dimmTempMax", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "dimm_temp_min": MoPropertyMeta("dimm_temp_min", "dimmTempMin", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "ulong", VersionMeta.Version111j, MoPropertyMeta.NAMING, None, None, None, None, [], []),
        "most_recent": MoPropertyMeta("most_recent", "mostRecent", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "proc_temp": MoPropertyMeta("proc_temp", "procTemp", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "proc_temp_avg": MoPropertyMeta("proc_temp_avg", "procTempAvg", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "proc_temp_max": MoPropertyMeta("proc_temp_max", "procTempMax", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "proc_temp_min": MoPropertyMeta("proc_temp_min", "procTempMin", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "temp": MoPropertyMeta("temp", "temp", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "temp_avg": MoPropertyMeta("temp_avg", "tempAvg", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "temp_max": MoPropertyMeta("temp_max", "tempMax", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "temp_min": MoPropertyMeta("temp_min", "tempMin", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
    }

    prop_map = {
        "IomI2CErrors": "iom_i2_c_errors", 
        "IomI2CErrorsAvg": "iom_i2_c_errors_avg", 
        "IomI2CErrorsMax": "iom_i2_c_errors_max", 
        "IomI2CErrorsMin": "iom_i2_c_errors_min", 
        "ambientTemp": "ambient_temp", 
        "ambientTempAvg": "ambient_temp_avg", 
        "ambientTempMax": "ambient_temp_max", 
        "ambientTempMin": "ambient_temp_min", 
        "childAction": "child_action", 
        "dimmTemp": "dimm_temp", 
        "dimmTempAvg": "dimm_temp_avg", 
        "dimmTempMax": "dimm_temp_max", 
        "dimmTempMin": "dimm_temp_min", 
        "dn": "dn", 
        "id": "id", 
        "mostRecent": "most_recent", 
        "procTemp": "proc_temp", 
        "procTempAvg": "proc_temp_avg", 
        "procTempMax": "proc_temp_max", 
        "procTempMin": "proc_temp_min", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "temp": "temp", 
        "tempAvg": "temp_avg", 
        "tempMax": "temp_max", 
        "tempMin": "temp_min", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.iom_i2_c_errors = None
        self.iom_i2_c_errors_avg = None
        self.iom_i2_c_errors_max = None
        self.iom_i2_c_errors_min = None
        self.ambient_temp = None
        self.ambient_temp_avg = None
        self.ambient_temp_max = None
        self.ambient_temp_min = None
        self.child_action = None
        self.dimm_temp = None
        self.dimm_temp_avg = None
        self.dimm_temp_max = None
        self.dimm_temp_min = None
        self.most_recent = None
        self.proc_temp = None
        self.proc_temp_avg = None
        self.proc_temp_max = None
        self.proc_temp_min = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.temp = None
        self.temp_avg = None
        self.temp_max = None
        self.temp_min = None
        self.thresholded = None
        self.time_collected = None

        ManagedObject.__init__(self, "EquipmentIOCardStatsHist", parent_mo_or_dn, **kwargs)



# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
This module contains the api used to provide compare and sync functionality
within ucsm or across ucsm.
"""

from __future__ import print_function

import re
import logging

from .. import ucsgenutils
from .. import ucscoreutils
from ..ucscoremeta import MoPropertyMeta, MoMeta
from ..ucsexception import UcsWarning, UcsValidationException
from ..ucsmo import GenericMo

log = logging.getLogger('ucs')

skip_mos = ["LsVersionBeh", "LsmaintAck", "LsIssues", "VnicIpV4PooledAddr",
            "VnicDynamicCon", "LsVConAssign", "ComputePooledSlot",
            "ComputePooledRackUnit", "VnicIPv4PooledIscsiAddr",
            "IppoolPooled", "IqnpoolPooled", "MacpoolPooled",
            "UuidpoolPooled", "VnicConnDef", "VnicFcGroupDef",
            "LsServerExtension"]


class _CompareStatus(object):
    """
    Internal class used as enum.
    """

    TYPES_DIFFERENT = 0
    PROPS_DIFFERENT = 1
    EQUAL = 2


class _PropDiff(object):
    """
    Internal class for property delta
    """

    def __init__(self, prop, old_value, new_value):
        self.prop = prop
        self.old_value = old_value
        self.new_value = new_value


class _MoDiff(object):
    """
    This class represents difference object.
    """

    REMOVE = "<="
    ADD_MODIFY = "=>"
    EQUAL = "=="

    def __init__(self, input_object, side_indicator, diff_property=None,
                 ref_values=None, diff_values=None):
        self.input_object = input_object
        self.dn = input_object.dn
        self.side_indicator = side_indicator
        self.diff_property = diff_property

        if ref_values:
            self.ref_prop_values = ref_values
        else:
            self.ref_prop_values = {}

        if diff_values:
            self.diff_prop_values = diff_values
        else:
            self.diff_prop_values = {}

    def get_prop_diff(self, prop):
        if prop in self.ref_prop_values and prop in self.diff_prop_values:
            prop_name = ""
            for key in self.ref_prop_values:
                if prop.lower() == key.lower():
                    prop_name = key
                    break
            return _PropDiff(prop_name, self.ref_prop_values[prop],
                             self.diff_prop_values[prop])
        return None


def _update_mo_dn_and_naming_props(mo, ref_dn):
    """
    Internal method to modify the naming properties of mo using dn.
    """

    # modify diffmo dn with refmo dn
    mo.__dict__['dn'] = ref_dn

    # modify diffmo rn with refmo rn
    ref_rn = re.sub(r'^.*/', '', ref_dn)
    mo.__dict__['rn'] = ref_rn

    # modify diff mo naming properties using ref_rn
    naming_prop_dict = ucscoreutils.get_naming_props(rn_str=ref_rn,
                                                     rn_pattern=mo.mo_meta.rn)
    for prop in naming_prop_dict:
        mo.__dict__[prop] = naming_prop_dict[prop]


def _translate_managed_object(mo, xlate_org, xlate_map):
    """
    Internal method used to translate a managed object which helps in comparing
    two mo with different dn.
    """

    if not xlate_org and not xlate_map:
        return mo

    mo = mo.clone()
    ref_dn = None
    if xlate_org is not None:
        match_obj = re.match(
            r'^(org-[\-\.:_a-zA-Z0-9]{1,16}/)*org-[\-\.:_a-zA-Z0-9]{1,16}',
            mo.dn)
        if match_obj:
            if mo.get_class_id() == "OrgOrg":
                ref_dn = re.sub("%s" % (match_obj.group(0)),
                                "%s" % xlate_org,
                                mo.dn)
            else:
                ref_dn = re.sub("^%s/" % (match_obj.group(0)),
                                "%s/" % xlate_org,
                                mo.dn)
            _update_mo_dn_and_naming_props(mo, ref_dn)

    if xlate_map is not None:
        diff_dn = mo.dn
        if diff_dn in xlate_map:
            ref_dn = xlate_map[diff_dn]
            _update_mo_dn_and_naming_props(mo, ref_dn)
        else:
            diff_dn = re.sub(r'[/]*[^/]+$', '', diff_dn)
            while diff_dn:
                if diff_dn not in xlate_map:
                    diff_dn = re.sub(r'[/]*[^/]+$', '', diff_dn)
                    continue

                ref_dn = re.sub("^%s/" % diff_dn,
                                "%s/" % xlate_map[diff_dn],
                                mo.dn)
                _update_mo_dn_and_naming_props(mo, ref_dn)
                break
    return mo


def _list_has_values(obj):
    """
    Internal function to check if obj is non empty list.
    """

    return isinstance(obj, list) and len(obj) > 0


def _should_skip_mo(mo):
    """
    Internal function to check if mo to be skipped from comparison.
    """

    if mo is None:
        return True
    if isinstance(mo, GenericMo):
        if ucsgenutils.word_u(mo.get_class_id()) in skip_mos:
            return True
    elif mo.get_class_id() in skip_mos or \
            mo.mo_meta.inp_out == MoMeta.ACCESS_TYPE_OUTPUTONLY or \
            (mo.mo_meta.inp_out == MoMeta.ACCESS_TYPE_IO
             and len(mo.mo_meta.access) == 1
             and mo.mo_meta.access[0] == "read-only"):
        return True
    return False


def _get_skip_props(mo, include_operational=False, version_filter=True):
    """
    Internal function to skip mo property if not to be considered for sync.
    """

    skip_props = []
    for prop in mo.prop_meta:
        mo_property_meta = mo.prop_meta[prop]
        if mo_property_meta is None:
            continue

        # not include operational property
        if not include_operational:
            if mo_property_meta.access in (MoPropertyMeta.INTERNAL,
                                           MoPropertyMeta.READ_ONLY):
                skip_props.append(prop)
        # checks if property is part of current or earlier ucsm schema
        if version_filter:
            version = mo.get_handle().version
            if version is None or version < mo_property_meta.version or \
               mo_property_meta.access == MoPropertyMeta.INTERNAL:
                skip_props.append(prop)
    return skip_props


def _compare_known_mo(from_mo, to_mo, diff, include_operational=False,
                      version_filter=True):
    """
    Internal function to compare if both the ref and diff obj is known mo.
    """

    from_mo_skip_props = None
    if not include_operational or version_filter:
        from_mo_skip_props = _get_skip_props(from_mo, include_operational,
                                             version_filter)

    # comparing known properties of ref mo
    for prop in from_mo.prop_meta:
        if from_mo_skip_props and prop in from_mo_skip_props:
            continue
        # if not exist in diff mo
        if not hasattr(to_mo, prop):
            log.debug("Property '%s' of '%s' does not exist in diff obj." % (
                prop, from_mo.dn))
            continue

        if getattr(from_mo, prop) != getattr(to_mo, prop):
            diff.append(prop)

    # comparing unknown properties of ref mo
    from_xtra_props = from_mo._ManagedObject__xtra_props
    to_xtra_props = to_mo._ManagedObject__xtra_props
    if not to_xtra_props:
        return
    for prop in from_xtra_props:
        if prop not in to_xtra_props:
            continue

        if from_xtra_props[prop].value != to_xtra_props[prop].value:
            if version_filter:
                UcsWarning("Ignoring xtra property '%s' of '%s'" % (
                    prop, from_mo.dn))
            else:
                diff.append(prop)


def _compare_unknown_mo(from_mo, to_mo, diff, version_filter=True):
    """
    Internal function to compare if any or both of the  ref and diff obj is
    unknown mo.
    """

    # both unknown mo
    if version_filter:
        return
    for prop in from_mo.properties:
        if prop not in to_mo.properties:
            continue
        if from_mo.properties[prop] != to_mo.properties[prop]:
            diff.append(prop)


def _compare(from_mo, to_mo, diff, include_operational=False,
             version_filter=True):
    """
    Internal method to support compare reference and difference object.
    """

    # compare mo of different types
    if from_mo.get_class_id() != to_mo.get_class_id():
        return _CompareStatus.TYPES_DIFFERENT

    # compare for unknown class_id
    if isinstance(from_mo, GenericMo) or isinstance(to_mo, GenericMo):
        _compare_unknown_mo(from_mo, to_mo, diff, version_filter)

    # compare for known class_id
    else:
        _compare_known_mo(from_mo, to_mo, diff, include_operational,
                          version_filter)

    if len(diff) > 0:
        return _CompareStatus.PROPS_DIFFERENT

    return _CompareStatus.EQUAL


def _compare_common_mo(ref_dict, diff_dict, include_operational=False,
                       version_filter=True, include_equal=False,
                       exclude_different=False):

    diff_output = []
    common_dns = set(ref_dict) & set(diff_dict)
    for dn in common_dns:
        ref_mo = ref_dict[dn]
        diff_mo = diff_dict[dn]
        diff_props = []

        # compare both mo for property and type
        diff_status = _compare(ref_mo, diff_mo, diff_props,
                               include_operational, version_filter)

        if diff_status == _CompareStatus.EQUAL and include_equal:
            mo_diff = _MoDiff(ref_mo, _MoDiff.EQUAL)
            diff_output.append(mo_diff)
            continue

        if exclude_different:
            continue

        if diff_status == _CompareStatus.TYPES_DIFFERENT:
            mo_diff = _MoDiff(ref_mo, _MoDiff.REMOVE)
            diff_output.append(mo_diff)
            mo_diff = _MoDiff(diff_mo, _MoDiff.ADD_MODIFY)
            diff_output.append(mo_diff)
        elif diff_status == _CompareStatus.PROPS_DIFFERENT:
            ref_values = {}
            diff_values = {}
            for prop in diff_props:
                ref_values[prop] = getattr(ref_mo, prop)
                diff_values[prop] = getattr(diff_mo, prop)
            mo_diff = _MoDiff(diff_mo, _MoDiff.ADD_MODIFY,
                              diff_props, ref_values, diff_values)
            diff_output.append(mo_diff)

    return diff_output


def compare_ucs_mo(ref_obj, diff_obj,
                   exclude_different=False,
                   include_equal=False,
                   version_filter=True,
                   include_operational=False,
                   xlate_org=None, xlate_map=None):
    """
    Compares the state of two managed objects with same dn.

    Args:
        ref_obj (list): list of Managed Objects of reference UCSM
        diff_obj (list): list of Managed Objects of difference UCSM
        exclude_different (bool): default:False. When True, compares MOs that
                                  exist on both reference and difference UCSM
        include_equal (bool): default:False. When True, also displays MOs which
                              are equal.
        version_filter (bool): default:True. When False, ignores properties
                               which is introduced in later UCSM version than
                               reference UCSM version.
        include_operational (bool): default:False. When True, compares all the
                                    properties of mo.
        xlate_org (str): org-dn of reference mo, compares objects of same type
                         and same rn under different org.
        xlate_map (dict) : {"difference_dn": "reference_dn"}, compares objects
                            of same type with different dn.
    Returns:
        List of MoDiff objects:
        MoDiff Object : dn - dn of Managed Object
                        input_object - Managed Object
                        side_indicator -
                            "=>" Add the diff obj to ref ucsm
                              or
                              Modify the ref object by diff object on ref ucsm

                            "<=" Removes the ref obj from ref ucsm

                            "==" object is equal on both ref and diff ucsm
                        diff_property  - property list with different value

    Example:
        #1
        ref_mos = [ref_handle.query_dn(dn="org-root/ls-sp")]
        diff_mos = [diff_handle.query_dn(dn="org-root/ls-sp")]
        compare_ucs_mo(ref_mos, diff_mos)

        #2
        ref_mos = [ref_handle.query_dn(dn="org-root/org-ref/ls-sp")]
        diff_mos = [diff_handle.query_dn(dn="org-root/org-diff/ls-sp")]
        compare_ucs_mo(ref_mos, diff_mos, xlate_org = "org-root/org-ref")

        #3
        ref_mos = [ref_handle.query_dn(dn="org-root/ls-ref")]
        diff_mos = [diff_handle.query_dn(dn="org-root/ls-diff")]
        compare_ucs_mo(ref_mos, diff_mos,
                       xlate_map = {"org-root/ls-diff": "org-root/ls-ref"})
    """

    reference_dict = {}
    difference_dict = {}
    diff_output = []

    if ref_obj is not None and _list_has_values(ref_obj):
        for mo in ref_obj:
            if _should_skip_mo(mo):
                continue
            reference_dict[mo.dn] = mo

    if diff_obj is not None and _list_has_values(diff_obj):
        for mo in diff_obj:
            if _should_skip_mo(mo):
                continue
            translated_mo = _translate_managed_object(mo, xlate_org, xlate_map)
            difference_dict[translated_mo.dn] = translated_mo

    if not exclude_different:
        only_ref_dns = set(reference_dict) - set(difference_dict)
        only_diff_dns = set(difference_dict) - set(reference_dict)

        for dn in only_ref_dns:
            diff_output.append(_MoDiff(reference_dict[dn],
                                       _MoDiff.REMOVE))

        for dn in only_diff_dns:
            diff_output.append(_MoDiff(difference_dict[dn],
                                       _MoDiff.ADD_MODIFY))

    diff_with_props = _compare_common_mo(reference_dict, difference_dict,
                                         include_operational,
                                         version_filter, include_equal,
                                         exclude_different)

    if diff_with_props:
        diff_output.extend(diff_with_props)

    return diff_output


def sync_ucs_mo(ref_handle, difference,
                delete_not_present=False,
                version_filter=True):
    """
    syncs the difference object on reference ucsm.
    In other words, make the state of reference ucsm for the respective
    ref object same as difference object on reference ucsm.

    Args:
        ref_handle (UcsHandle): connect handle of reference ucsm
        difference (list of MoDiff objects): output of compare-ucs-mo api
        delete_not_present (bool): by dafault False. If set to true, will
                                   delete ref mo which does not exist on
                                   difference ucsm
        version_filter (bool): by default True: If set to False, ignore
                                  properties which is introduced in later ucsm
                                  version than reference ucsm

    Returns:
        None

    Example:
        #1
        ref_mos = [ref_handle.query_dn(dn="org-root/ls-sp")]
        diff_mos = [diff_handle.query_dn(dn="org-root/ls-sp")]
        difference = compare_ucs_mo(ref_handle, ref_mos,diff_handle, diff_mos)
        sync_ucs_mo(ref_handle, difference=difference, delete_not_present=True)
    """

    if difference is None or not _list_has_values(difference):
        raise UcsValidationException(
            "difference object parameter is not provided.")

    to_commit = False

    for mo_diff in difference:
        mo = mo_diff.input_object
        class_id = mo.get_class_id()

        if isinstance(mo, GenericMo):
            UcsWarning("Ignoring '%s'.Unknown ClasId '%s'" % (mo.dn, class_id))
            continue

        # Remove
        if mo_diff.side_indicator == _MoDiff.REMOVE and delete_not_present:
            log.debug("removing mo '%s'." % mo.dn)
            ref_handle.remove_mo(mo)
            to_commit = True

        if version_filter:
            mo_meta = mo.mo_meta
            if ref_handle.version < mo_meta.version:
                UcsWarning("Ignoring unsupported class_id '%s' for dn '%s'" %
                           (class_id, mo.dn))
                continue

        # Add or Modify
        if mo_diff.side_indicator == _MoDiff.ADD_MODIFY:
            add_exists = False
            if not isinstance(mo, GenericMo) and 'Add' in mo.mo_meta.verbs:
                add_exists = True

            # Add
            if add_exists and (mo_diff.diff_property is None
                               or len(mo_diff.diff_property) == 0):
                log.debug("adding mo '%s'" % mo.dn)
                mo.mark_dirty()
                ref_handle.add_mo(mo)
                to_commit = True

            # Modify the Managed Object
            else:
                if mo_diff.diff_property is None \
                        or len(mo_diff.diff_property) == 0:
                    continue
                set_flag = False
                for prop in mo_diff.diff_property:
                    if mo.prop_meta[prop].access == MoPropertyMeta.READ_WRITE:
                        setattr(mo, prop, getattr(mo, prop))
                        set_flag = True
                if not set_flag:
                    log.debug("No Configurable Properties Changed for mo '%s'"
                              % mo.dn)
                else:
                    log.debug("set mo '%s'" % mo.dn)
                    ref_handle.set_mo(mo)
                    to_commit = True

    if to_commit:
        ref_handle.commit()


def write_mo_diff(diff_obj):
    """
    Writes the difference managedObject(output of CompareManagedObject)
    on the terminal.
    """

    tab_size = 8
    if not _list_has_values(diff_obj):
        return

    if isinstance(diff_obj[0], _MoDiff):
        print("dn".ljust(tab_size * 10), "input_object".ljust(tab_size * 4),
              "side_indicator".ljust(tab_size * 3), "diff_property")
        print("--".ljust(tab_size * 10), "-----------".ljust(tab_size * 4),
              "-------------".ljust(tab_size * 3), "------------")
    diff_obj_mod = []
    for mo_diff in diff_obj:
        if not isinstance(mo_diff, _MoDiff):
            continue
        diff_obj_mod.append(mo_diff)

    for mo_diff in sorted(diff_obj_mod, key=lambda mo: mo.dn):
        print(str(mo_diff.dn).ljust(tab_size * 10),
              str(mo_diff.input_object.get_class_id()).ljust(tab_size * 4),
              str(mo_diff.side_indicator).ljust(tab_size * 3),
              str(sorted(mo_diff.diff_property))
              if mo_diff.diff_property else str(mo_diff.diff_property))



"""This module contains the general information for StorageNvmeStatsHist ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class StorageNvmeStatsHistConsts:
    MOST_RECENT_FALSE = "false"
    MOST_RECENT_NO = "no"
    MOST_RECENT_TRUE = "true"
    MOST_RECENT_YES = "yes"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"
    TEMPERATURE_NOT_APPLICABLE = "not-applicable"
    TEMPERATURE_AVG_NOT_APPLICABLE = "not-applicable"
    TEMPERATURE_MAX_NOT_APPLICABLE = "not-applicable"
    TEMPERATURE_MIN_NOT_APPLICABLE = "not-applicable"


class StorageNvmeStatsHist(ManagedObject):
    """This is StorageNvmeStatsHist class."""

    consts = StorageNvmeStatsHistConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("StorageNvmeStatsHist", "storageNvmeStatsHist", "[id]", VersionMeta.Version312b, "OutputOnly", 0xf, [], ["read-only"], ['storageNvmeStats'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version312b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "drive_life_used_percentage": MoPropertyMeta("drive_life_used_percentage", "driveLifeUsedPercentage", "uint", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "drive_life_used_percentage_avg": MoPropertyMeta("drive_life_used_percentage_avg", "driveLifeUsedPercentageAvg", "uint", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "drive_life_used_percentage_max": MoPropertyMeta("drive_life_used_percentage_max", "driveLifeUsedPercentageMax", "uint", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "drive_life_used_percentage_min": MoPropertyMeta("drive_life_used_percentage_min", "driveLifeUsedPercentageMin", "uint", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "id": MoPropertyMeta("id", "id", "ulong", VersionMeta.Version312b, MoPropertyMeta.NAMING, None, None, None, None, [], []),
        "life_left_in_days": MoPropertyMeta("life_left_in_days", "lifeLeftInDays", "uint", VersionMeta.Version402a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "life_left_in_days_avg": MoPropertyMeta("life_left_in_days_avg", "lifeLeftInDaysAvg", "uint", VersionMeta.Version402a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "life_left_in_days_max": MoPropertyMeta("life_left_in_days_max", "lifeLeftInDaysMax", "uint", VersionMeta.Version402a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "life_left_in_days_min": MoPropertyMeta("life_left_in_days_min", "lifeLeftInDaysMin", "uint", VersionMeta.Version402a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "most_recent": MoPropertyMeta("most_recent", "mostRecent", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version312b, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "temperature": MoPropertyMeta("temperature", "temperature", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "temperature_avg": MoPropertyMeta("temperature_avg", "temperatureAvg", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "temperature_max": MoPropertyMeta("temperature_max", "temperatureMax", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "temperature_min": MoPropertyMeta("temperature_min", "temperatureMin", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "driveLifeUsedPercentage": "drive_life_used_percentage", 
        "driveLifeUsedPercentageAvg": "drive_life_used_percentage_avg", 
        "driveLifeUsedPercentageMax": "drive_life_used_percentage_max", 
        "driveLifeUsedPercentageMin": "drive_life_used_percentage_min", 
        "id": "id", 
        "lifeLeftInDays": "life_left_in_days", 
        "lifeLeftInDaysAvg": "life_left_in_days_avg", 
        "lifeLeftInDaysMax": "life_left_in_days_max", 
        "lifeLeftInDaysMin": "life_left_in_days_min", 
        "mostRecent": "most_recent", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "temperature": "temperature", 
        "temperatureAvg": "temperature_avg", 
        "temperatureMax": "temperature_max", 
        "temperatureMin": "temperature_min", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.drive_life_used_percentage = None
        self.drive_life_used_percentage_avg = None
        self.drive_life_used_percentage_max = None
        self.drive_life_used_percentage_min = None
        self.life_left_in_days = None
        self.life_left_in_days_avg = None
        self.life_left_in_days_max = None
        self.life_left_in_days_min = None
        self.most_recent = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.temperature = None
        self.temperature_avg = None
        self.temperature_max = None
        self.temperature_min = None
        self.thresholded = None
        self.time_collected = None

        ManagedObject.__init__(self, "StorageNvmeStatsHist", parent_mo_or_dn, **kwargs)



"""This module contains the general information for IqnpoolAddr ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class IqnpoolAddrConsts:
    ASSIGNED_FALSE = "false"
    ASSIGNED_NO = "no"
    ASSIGNED_TRUE = "true"
    ASSIGNED_YES = "yes"
    OWNER_END_POINT = "end-point"
    OWNER_POOL = "pool"


class IqnpoolAddr(ManagedObject):
    """This is IqnpoolAddr class."""

    consts = IqnpoolAddrConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("IqnpoolAddr", "iqnpoolAddr", "[name]", VersionMeta.Version201m, "InputOutput", 0x3f, [], ["read-only"], ['iqnpoolUniverse'], ['faultInst', 'iqnpoolPoolable'], ["Get"])

    prop_meta = {
        "assigned": MoPropertyMeta("assigned", "assigned", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "assigned_to_dn": MoPropertyMeta("assigned_to_dn", "assignedToDn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "global_assigned_cnt": MoPropertyMeta("global_assigned_cnt", "globalAssignedCnt", "uint", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "global_defined_cnt": MoPropertyMeta("global_defined_cnt", "globalDefinedCnt", "uint", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version201m, MoPropertyMeta.NAMING, 0x8, 1, 510, None, [], []),
        "owner": MoPropertyMeta("owner", "owner", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["end-point", "pool"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "assigned": "assigned", 
        "assignedToDn": "assigned_to_dn", 
        "childAction": "child_action", 
        "dn": "dn", 
        "globalAssignedCnt": "global_assigned_cnt", 
        "globalDefinedCnt": "global_defined_cnt", 
        "name": "name", 
        "owner": "owner", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.assigned = None
        self.assigned_to_dn = None
        self.child_action = None
        self.global_assigned_cnt = None
        self.global_defined_cnt = None
        self.owner = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "IqnpoolAddr", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FabricPathConn ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FabricPathConnConsts:
    C_TYPE_MUX = "mux"
    C_TYPE_MUX_ACCESS = "mux-access"
    C_TYPE_MUX_FABRIC = "mux-fabric"
    C_TYPE_MUX_FABRICPC = "mux-fabricpc"
    C_TYPE_MUX_FABRICPC_TO_CHPC = "mux-fabricpc-to-chpc"
    C_TYPE_MUX_FABRICPC_TO_HOSTPC = "mux-fabricpc-to-hostpc"
    C_TYPE_MUX_FABRICPC_TO_HOSTPORT = "mux-fabricpc-to-hostport"
    C_TYPE_MUX_FABRICPORT_TO_HOSTPC = "mux-fabricport-to-hostpc"
    C_TYPE_MUX_HOSTPC_TO_ADAPTORPC = "mux-hostpc-to-adaptorpc"
    C_TYPE_MUX_TO_APPLIANCE = "mux-to-appliance"
    C_TYPE_MUX_TO_CHASSIS = "mux-to-chassis"
    C_TYPE_MUX_TO_HOST = "mux-to-host"
    C_TYPE_SWITCH_ACCESS = "switch-access"
    C_TYPE_SWITCH_FABRIC = "switch-fabric"
    C_TYPE_SWITCH_FABRICPC = "switch-fabricpc"
    C_TYPE_SWITCH_TO_HOST = "switch-to-host"
    C_TYPE_SWITCH_TO_MUX = "switch-to-mux"
    C_TYPE_SWITCHPC_TO_HOSTPC = "switchpc-to-hostpc"


class FabricPathConn(ManagedObject):
    """This is FabricPathConn class."""

    consts = FabricPathConnConsts()
    naming_props = set(['cType'])

    mo_meta = MoMeta("FabricPathConn", "fabricPathConn", "xc-[c_type]", VersionMeta.Version101e, "InputOutput", 0x7f, [], ["read-only"], ['fabricPath'], ['fabricPathEp'], ["Get"])

    prop_meta = {
        "c_type": MoPropertyMeta("c_type", "cType", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x2, None, None, None, ["mux", "mux-access", "mux-fabric", "mux-fabricpc", "mux-fabricpc-to-chpc", "mux-fabricpc-to-hostpc", "mux-fabricpc-to-hostport", "mux-fabricport-to-hostpc", "mux-hostpc-to-adaptorpc", "mux-to-appliance", "mux-to-chassis", "mux-to-host", "switch-access", "switch-fabric", "switch-fabricpc", "switch-to-host", "switch-to-mux", "switchpc-to-hostpc"], ["0-255"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|server|chassis|internal|external),){0,5}(defaultValue|unknown|server|chassis|internal|external){0,1}""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []),
    }

    prop_map = {
        "cType": "c_type", 
        "childAction": "child_action", 
        "dn": "dn", 
        "locale": "locale", 
        "name": "name", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "transport": "transport", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, c_type, **kwargs):
        self._dirty_mask = 0
        self.c_type = c_type
        self.child_action = None
        self.locale = None
        self.name = None
        self.sacl = None
        self.status = None
        self.transport = None
        self.type = None

        ManagedObject.__init__(self, "FabricPathConn", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FirmwareUpgradeDetail ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FirmwareUpgradeDetailConsts:
    CATEGORY_CATALOG = "catalog"
    CATEGORY_CONFIG = "config"
    CATEGORY_DATA_LOAD = "data-load"
    CATEGORY_FAULTS = "faults"
    CATEGORY_OTHER = "other"
    CATEGORY_SERVER_REBOOT = "server-reboot"
    SEVERITY_ERROR = "error"
    SEVERITY_FATAL = "fatal"
    SEVERITY_INFO = "info"
    SEVERITY_UNKNOWN = "unknown"
    SEVERITY_WARN = "warn"


class FirmwareUpgradeDetail(ManagedObject):
    """This is FirmwareUpgradeDetail class."""

    consts = FirmwareUpgradeDetailConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("FirmwareUpgradeDetail", "firmwareUpgradeDetail", "id-[id]", VersionMeta.Version211a, "InputOutput", 0x3f, [], ["admin"], ['firmwareUpgradeInfo'], [], ["Get"])

    prop_meta = {
        "category": MoPropertyMeta("category", "category", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["catalog", "config", "data-load", "faults", "other", "server-reboot"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "description": MoPropertyMeta("description", "description", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version211a, MoPropertyMeta.NAMING, 0x8, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "severity": MoPropertyMeta("severity", "severity", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["error", "fatal", "info", "unknown", "warn"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "category": "category", 
        "childAction": "child_action", 
        "description": "description", 
        "dn": "dn", 
        "id": "id", 
        "rn": "rn", 
        "sacl": "sacl", 
        "severity": "severity", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.category = None
        self.child_action = None
        self.description = None
        self.sacl = None
        self.severity = None
        self.status = None

        ManagedObject.__init__(self, "FirmwareUpgradeDetail", parent_mo_or_dn, **kwargs)



"""This module contains the general information for AdaptorIscsiProt ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AdaptorIscsiProtConsts:
    TCP_TIME_STAMP_FALSE = "false"
    TCP_TIME_STAMP_NO = "no"
    TCP_TIME_STAMP_TRUE = "true"
    TCP_TIME_STAMP_YES = "yes"


class AdaptorIscsiProt(ManagedObject):
    """This is AdaptorIscsiProt class."""

    consts = AdaptorIscsiProtConsts()
    naming_props = set([])

    mo_meta = MoMeta("AdaptorIscsiProt", "adaptorIscsiProt", "iscsi-prot", VersionMeta.Version201m, "InputOutput", 0x1f, [], ["read-only"], ['adaptorHostIscsiIf'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "connection_time_out": MoPropertyMeta("connection_time_out", "connectionTimeOut", "ushort", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-255"]),
        "dhcp_time_out": MoPropertyMeta("dhcp_time_out", "dhcpTimeOut", "ushort", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["60-300"]),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, None, None, None, None, [], []),
        "initiator_name": MoPropertyMeta("initiator_name", "initiatorName", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "lun_busy_retry_count": MoPropertyMeta("lun_busy_retry_count", "lunBusyRetryCount", "ushort", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-60"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "tcp_time_stamp": MoPropertyMeta("tcp_time_stamp", "tcpTimeStamp", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "connectionTimeOut": "connection_time_out", 
        "dhcpTimeOut": "dhcp_time_out", 
        "dn": "dn", 
        "fltAggr": "flt_aggr", 
        "initiatorName": "initiator_name", 
        "lunBusyRetryCount": "lun_busy_retry_count", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "tcpTimeStamp": "tcp_time_stamp", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.connection_time_out = None
        self.dhcp_time_out = None
        self.flt_aggr = None
        self.initiator_name = None
        self.lun_busy_retry_count = None
        self.sacl = None
        self.status = None
        self.tcp_time_stamp = None

        ManagedObject.__init__(self, "AdaptorIscsiProt", parent_mo_or_dn, **kwargs)



"""This module contains the general information for OsAgent ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class OsAgentConsts:
    LAST_CMD_NONE = "none"
    LAST_EVT_NONE = "none"
    PREV_CMD_NONE = "none"
    PREV_EVT_NONE = "none"
    TYPE_HOST_AGENT = "hostAgent"
    TYPE_INDETERMINATE = "indeterminate"
    TYPE_PNUOS_AGENT = "pnuosAgent"


class OsAgent(ManagedObject):
    """This is OsAgent class."""

    consts = OsAgentConsts()
    naming_props = set([])

    mo_meta = MoMeta("OsAgent", "osAgent", "agent", VersionMeta.Version101e, "InputOutput", 0x1f, [], ["read-only"], ['computeBlade', 'computeRackUnit', 'computeServerUnit'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "last_cmd": MoPropertyMeta("last_cmd", "lastCmd", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["none"], []),
        "last_evt": MoPropertyMeta("last_evt", "lastEvt", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["none"], []),
        "last_evt_ts": MoPropertyMeta("last_evt_ts", "lastEvtTs", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "prev_cmd": MoPropertyMeta("prev_cmd", "prevCmd", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["none"], []),
        "prev_evt": MoPropertyMeta("prev_evt", "prevEvt", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["none"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["hostAgent", "indeterminate", "pnuosAgent"], []),
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "version": MoPropertyMeta("version", "version", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "lastCmd": "last_cmd", 
        "lastEvt": "last_evt", 
        "lastEvtTs": "last_evt_ts", 
        "prevCmd": "prev_cmd", 
        "prevEvt": "prev_evt", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
        "vendor": "vendor", 
        "version": "version", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.last_cmd = None
        self.last_evt = None
        self.last_evt_ts = None
        self.prev_cmd = None
        self.prev_evt = None
        self.sacl = None
        self.status = None
        self.type = None
        self.vendor = None
        self.version = None

        ManagedObject.__init__(self, "OsAgent", parent_mo_or_dn, **kwargs)



"""This module contains the general information for InitiatorUnitEp ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class InitiatorUnitEpConsts:
    BOOT_FALSE = "false"
    BOOT_NO = "no"
    BOOT_TRUE = "true"
    BOOT_YES = "yes"
    ID_UNSPECIFIED = "unspecified"
    LC_ALLOCATED = "allocated"
    LC_AVAILABLE = "available"
    LC_DEALLOCATED = "deallocated"
    LC_REPURPOSED = "repurposed"
    PHY_ID_UNSPECIFIED = "unspecified"
    PROT_DERIVED = "derived"
    PROT_FC = "fc"
    PROT_ISCSI = "iscsi"


class InitiatorUnitEp(ManagedObject):
    """This is InitiatorUnitEp class."""

    consts = InitiatorUnitEpConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("InitiatorUnitEp", "initiatorUnitEp", "unit-[id]", VersionMeta.Version211a, "InputOutput", 0x3f, [], ["read-only"], ['initiatorRequestorGrpEp'], [], [None])

    prop_meta = {
        "boot": MoPropertyMeta("boot", "boot", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "ha": MoPropertyMeta("ha", "ha", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|none|initiator|target|fabric),){0,4}(defaultValue|none|initiator|target|fabric){0,1}""", [], []),
        "id": MoPropertyMeta("id", "id", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, 0x8, None, None, None, ["unspecified"], ["0-4294967295"]),
        "item_dn": MoPropertyMeta("item_dn", "itemDn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "lc": MoPropertyMeta("lc", "lc", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["allocated", "available", "deallocated", "repurposed"], []),
        "phy_id": MoPropertyMeta("phy_id", "phyId", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unspecified"], ["0-4294967295"]),
        "prot": MoPropertyMeta("prot", "prot", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["derived", "fc", "iscsi"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "boot": "boot", 
        "childAction": "child_action", 
        "dn": "dn", 
        "epDn": "ep_dn", 
        "ha": "ha", 
        "id": "id", 
        "itemDn": "item_dn", 
        "lc": "lc", 
        "phyId": "phy_id", 
        "prot": "prot", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.boot = None
        self.child_action = None
        self.ep_dn = None
        self.ha = None
        self.item_dn = None
        self.lc = None
        self.phy_id = None
        self.prot = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "InitiatorUnitEp", parent_mo_or_dn, **kwargs)
